@@ -10,14 +10,17 @@ import sys
 
 
 class ProgressBar(object):
-    def __init__(self, items=None, maxlen=25, char='█', show_on_update=False, items_per_sec=1):
-        self.completed = 0
+    def __init__(self, items=None, completed=0, maxlen=25, char='█', show_on_update=False, ips=1, lsttime=None):
+        self.completed = completed
         self.items = items
         self.maxlen = maxlen
         self.pos = 0
         self.char = char
-        self.items_per_sec = items_per_sec
-        self.last_time = time.time()
+        self.items_per_sec = ips
+        if lsttime:
+            self.last_time = lsttime
+        else:
+            self.last_time = time.time()
         self.show_on_update = show_on_update
 
     def __repr__(self):
@@ -39,18 +42,19 @@ class ProgressBar(object):
         return self.completed / other
 
     def __iadd__(self, other):
-        a = ProgressBar(self.items, self.maxlen, self.char, self.show_on_update, self.items_per_sec)
+        a = ProgressBar(self.items, self.completed, self.maxlen, self.char,
+                        self.show_on_update, self.items_per_sec, self.last_time)
         a.update(self.completed + other)
         return a
 
     def format_time(self):
         secs = self.items_per_sec*(self.items-self.completed)
-        return f'{int(secs//3600)}:{str(int(secs//60)%60).zfill(2)}:{str(int(secs%60)).zfill(2)}'
+        return f'{int(secs//3600)}:{str(int(secs//60)%60).zfill(2)}:{str(int(secs%60)).zfill(2)} '
 
     def show(self):
         st = ''
         if self.items:
-            st = self.format_time() + ' remaining '
+            st = 'Eta: ' + self.format_time() + '| '
             ips = self.items_per_sec
             if ips < 1:
                 st += str(round(1/ips, 2)) + ' items/s'
@@ -59,14 +63,14 @@ class ProgressBar(object):
 
         sys.stdout.write(
             f'{f"{str(self.completed).rjust(int(log(50,10)+.5))}/{self.items}" if self.items else ""} \
-Completed \
 {str(round(self.pos*100,2)).ljust(5)}% \
 [{(self.char*int(self.pos*self.maxlen)).ljust(self.maxlen)}] {st}\t\r')
 
     def update(self, completed):
         if self.items:
-            self.items_per_sec += .05 * \
-                ((time.time() - self.last_time) - self.items_per_sec)
+            t = time.time() - self.last_time
+            comp = completed - self.completed
+            self.items_per_sec += .05 * (comp/t - self.items_per_sec)
             self.last_time = time.time()
             self.completed = completed
             self.pos = completed/self.items
@@ -78,7 +82,7 @@ Completed \
 
 if __name__ == '__main__':
     import random
-    prog = ProgressBar(40000000000, show_on_update=True)
-    for i in range(100):
-        time.sleep(random.random()/5)
+    prog = ProgressBar(30, show_on_update=True, ips=1.5)
+    for i in range(prog.items):
+        time.sleep(.25)
         prog += 1
